<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://http://www.dynamicweblab.com/
 * @since      1.0.0
 *
 * @package    Wp_Team_Manager
 * @subpackage Wp_Team_Manager/admin
 */

/**
 * Team manager settings class
 */
 class Wp_Team_Manager_Settings{

    public function __construct() {
        add_action('admin_menu', [ $this, 'tm_create_menu'] );
    }


    /**
     * create plugin settings menu
     *
     * @since 1.0
     */
    public function tm_create_menu() {

        add_submenu_page( 
            'edit.php?post_type=team_manager', 
            'Settings', 
            'Settings', 
            'manage_options', 
            'team_manager', 
            [ $this, 'team_manager_setting_function'] 
        );

        add_action( 'admin_init', [ $this, 'register_tm_settings'] );

    }

    /**
     * Register settings menu
     *
     * @since 1.0
     */
    function register_tm_settings() {
        register_setting( 'tm-settings-group', 'tm_social_size' );
        register_setting( 'tm-settings-group', 'tm_link_new_window' );
        register_setting( 'tm-settings-group', 'single_team_member_view' );
        register_setting( 'tm-settings-group', 'tm_custom_css' );
        register_setting( 'tm-settings-group', 'tm_custom_template' );
    }

    /**
     * Register settings function
     *
     * @since 1.0
     */
    function team_manager_setting_function() {
        ?>
        <div class="wrap">
            <h2><?php esc_html_e('Team Manager settings', 'wp-team-manager'); ?></h2>
            
            <?php settings_errors(); ?>
            
            <form method="post" action="options.php">
                <?php 
                    settings_fields( 'tm-settings-group' );
                    do_settings_sections( 'tm-settings-group' );
                    $tm_social_size = get_option('tm_social_size');
                    $tm_custom_css = get_option('tm_custom_css');
                    $tm_link_new_window = get_option('tm_link_new_window');
                    $single_team_member_view = get_option('single_team_member_view');
                ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">
                            <label>
                                <?php esc_html_e('Social icon size (PX)','wp-team-manager'); ?>
                            </label>
                        </th>
                        <td>
                        <input class="form-control" id="tm_social_size" name="tm_social_size" type="number" value="<?php echo esc_html($tm_social_size); ?>">
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">
                            <label>
                                <?php esc_html_e('Open social links on new window','wp-team-manager'); ?>
                            </label>
                        </th>
                        <td>
                            <input type="checkbox" name="tm_link_new_window" value="True" <?php checked( $tm_link_new_window, 'True' ); ?>><?php echo esc_html__('Yes', 'wp-team-manager'); ?>
                        </td>
                    </tr>  
                    <tr valign="top">
                        <th scope="row">
                            <label>
                                <?php _e('Disable single team member view','wp-team-manager'); ?>
                            </label>
                        </th>
                        <td>
                            <input type="checkbox" name="single_team_member_view" value="True" <?php checked( $single_team_member_view, 'True' ); ?>><?php echo esc_html__('Yes', 'wp-team-manager'); ?>
                        </td>
                    </tr>              
                </table>
            
                <!-- Custom CSS -->
                <h3 class="wptm_title"><?php esc_html_e('CSS', 'wp-team-manager'); ?></h3>
                <p><?php esc_html_e('Add custom CSS for Team Manager', 'wp-team-manager'); ?></p>
                <textarea name="tm_custom_css" id="tm_custom_css" class="wp-editor-area" rows="10" cols="80"><?php echo esc_textarea($tm_custom_css); ?></textarea>   
            
                <?php submit_button(); ?>
            </form>
        
            <!-- Support -->
            <div id="wptm_support">
                <h3><?php esc_html_e('Support & bug report', 'wp-team-manager'); ?></h3>
                <p><?php printf(__('If you have some idea to improve this plugin or any bug to report, please email me at : <a href="%1$s">%2$s</a>', 'wp-team-manager'), 'mailto:dynamicweblab@gmail.com?subject=[wp-team-manager] Bug', 'dynamicweblab@gmail.com'); ?></p>
                <p><?php printf(__('You like this plugin ? Then please provide some support by <a href="%1$s" target="_blank">voting for it</a> and/or says that <a href="%2$s" target="_blank">it works</a> for your WordPress installation on the official WordPress plugins repository.', 'wp-team-manager'), 'http://wordpress.org/plugins/wp-team-manager/', 'http://wordpress.org/plugins/wp-team-manager/'); ?></p>
            </div>
        </div>

    <?php 
    } 
 }

 new Wp_Team_Manager_Settings();