<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.dynamicweblab.com/
 * @since             2.0.2
 * @package           Wp_Team_Manager
 *
 * @wordpress-plugin
 * Plugin Name:       WordPress Team Manager
 * Plugin URI:        
 * Description:       This plugin allows you to manage the members of your team or staff and display them using shortcode.
 * Version:           2.0.17
 * Author:            Dynamic Web Lab
 * Author URI:        https:///www.dynamicweblab.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wp-team-manager
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * This is mane class for the plugin
 */
final class Wp_Team_Manager {

	/**
	 * Plugin version
	 *
	 * @var string
	 */
	const version = '2.0.17';

	private function __construct() {

		$this->define_constants();

		register_activation_hook( __FILE__, [$this,'activate_wp_team_manager'] );
		register_deactivation_hook( __FILE__, [$this,'deactivate_wp_team_manager'] );
		
		add_action( 'init', [ $this, 'load_plugin_text_domain' ] );
		add_action( 'plugins_loaded', [ $this, 'wp_team_manager_file_includes' ] );

	}

	/**
	 * Load Textdomain
	 *
	 * Load plugin localization files.
	 *
	 * @access public
	 */
	public function load_plugin_text_domain() {
		load_plugin_textdomain( 'wp-team-manager', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Add version number on option table
	 *
	 *
	 * @since    1.0.0
	 */
	public function activate_wp_team_manager() {
		$installed = get_option( 'wp_team_manager_isntalled' );

		if ( ! $installed ) {
			update_option( 'wp_team_manager_isntalled', time() );
		}

		update_option( 'wp_team_manager_version', TM_VERSION );
	}

	/**
	 * Function torun when plugin deactivate 
	 *
	 *
	 * @since    1.0.0
	 */
	public function deactivate_wp_team_manager() {

	}

	/**
	 * Inisialize Plugin instence
	 *
	 * @access public
	 * @static
	 *
	 * @return \Wp_Team_Manager
	 */
	public static function init() {

		$instence = false;

		if ( ! $instence ) {
			$instence = new self();
		}

		return $instence;
	}

	/**
	 * defin plugin constence
	 *
	 * @void
	 */
	public function define_constants() {

		define( 'TM_VERSION', self::version );
		define( 'TM_FILE', __FILE__ );
		define( 'TM_PATH', __DIR__ );
		define( 'TM_URL', plugins_url( '', TM_FILE ) );
		define( 'TM_ADMIN_ASSETS', TM_URL . '/admin/assets' );
		define( 'TM_PUBLIC', TM_URL . '/public' );

	}

    /**
	 * Initialize the plugin
	 *
	 * Validates that Elementor is already loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed include the plugin class.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function wp_team_manager_file_includes() {

		require_once TM_PATH . '/includes/class-post-type.php';
		require_once TM_PATH . '/lib/cmb2/init.php';
		require_once TM_PATH . '/includes/helper.php';
		require_once TM_PATH . '/includes/functions.php';
		require_once TM_PATH . '/admin/class-shortcode-generator.php';
		require_once TM_PATH . '/admin/class-wp-team-manager-admin.php';
		require_once TM_PATH . '/public/class-wp-team-manager-public.php';
		require_once TM_PATH . '/public/class-shortcodes.php';
		require_once TM_PATH . '/admin/class-settings.php';
		require_once TM_PATH . '/includes/metaboxes/CMB2_Metabox.php';

	}

}

/**
 * Isnisial The main class
 *
 * @return false|Wp_Team_Manager
 * 
 * @since    1.0.0
 */
function run_wp_team_manager() {
	return Wp_Team_Manager::init();
}

run_wp_team_manager();